@@ -6,17 +6,27 @@
 
 #include <QObject>
 
-#include <QTest>
 #include <QSignalSpy>
+#include <QTest>
 
+#include <QLoggingCategory>
 #include <QQmlApplicationEngine>
 
 #include <KConcatenateRowsProxyModel>
 
+#ifdef IMPORT_ITEMMODELSPLUGIN
+#include <QPluginLoader>
+Q_IMPORT_PLUGIN(Plugin)
+#endif
 class tst_KConcatenateRowsQml : public QObject
 {
     Q_OBJECT
 private Q_SLOTS:
+    void initTestCase()
+    {
+        // avoid deprecation warning
+        QLoggingCategory::setFilterRules(QStringLiteral("kf.itemmodels.quick.deprecations.*=false"));
+    }
     void testQmlLoad();
 };
 
@@ -27,7 +37,7 @@ void tst_KConcatenateRowsQml::testQmlLoad()
 
     QCOMPARE(app.rootObjects().count(), 1);
 
-    auto concatModel = qobject_cast<KConcatenateRowsProxyModel*>(app.rootObjects().first());
+    auto concatModel = qobject_cast<KConcatenateRowsProxyModel *>(app.rootObjects().first());
     QVERIFY(concatModel);
 
     QCOMPARE(concatModel->rowCount(), 4);
