@@ -1,12 +1,12 @@
-#include <QSignalSpy>
-#include <QSortFilterProxyModel>
-#include <QTest>
-#include <QStandardItemModel>
 #include <QIdentityProxyModel>
 #include <QItemSelectionModel>
+#include <QSignalSpy>
+#include <QSortFilterProxyModel>
+#include <QStandardItemModel>
+#include <QTest>
 
-#include <kconcatenaterowsproxymodel.h>
 #include "test_model_helpers.h"
+#include <kconcatenaterowsproxymodel.h>
 using namespace TestModelHelpers;
 
 Q_DECLARE_METATYPE(QModelIndex)
@@ -46,15 +46,15 @@ private Q_SLOTS:
 
         // Then the proxy should show 2 rows
         QCOMPARE(pm.rowCount(), 2);
-        QCOMPARE(extractRowTexts(&pm, 0), QString("ABC"));
-        QCOMPARE(extractRowTexts(&pm, 1), QString("DEF"));
+        QCOMPARE(extractRowTexts(&pm, 0), QStringLiteral("ABC"));
+        QCOMPARE(extractRowTexts(&pm, 1), QStringLiteral("DEF"));
 
         // ... and correct headers
-        QCOMPARE(pm.headerData(0, Qt::Horizontal).toString(), QString("H1"));
-        QCOMPARE(pm.headerData(1, Qt::Horizontal).toString(), QString("H2"));
-        QCOMPARE(pm.headerData(2, Qt::Horizontal).toString(), QString("H3"));
-        QCOMPARE(pm.headerData(0, Qt::Vertical).toString(), QString("One"));
-        QCOMPARE(pm.headerData(1, Qt::Vertical).toString(), QString("Two"));
+        QCOMPARE(pm.headerData(0, Qt::Horizontal).toString(), QStringLiteral("H1"));
+        QCOMPARE(pm.headerData(1, Qt::Horizontal).toString(), QStringLiteral("H2"));
+        QCOMPARE(pm.headerData(2, Qt::Horizontal).toString(), QStringLiteral("H3"));
+        QCOMPARE(pm.headerData(0, Qt::Vertical).toString(), QStringLiteral("One"));
+        QCOMPARE(pm.headerData(1, Qt::Vertical).toString(), QStringLiteral("Two"));
 
         QVERIFY(!pm.canFetchMore(QModelIndex()));
     }
@@ -65,11 +65,12 @@ private Q_SLOTS:
         KConcatenateRowsProxyModel pm;
 
         // When adding two empty models
-        QSignalSpy rowATBISpy(&pm, SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)));
-        QSignalSpy rowInsertedSpy(&pm, SIGNAL(rowsInserted(QModelIndex,int,int)));
-        QSignalSpy rowATBRSpy(&pm, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)));
-        QSignalSpy rowRemovedSpy(&pm, SIGNAL(rowsRemoved(QModelIndex,int,int)));
-        QIdentityProxyModel i1, i2;
+        QSignalSpy rowATBISpy(&pm, SIGNAL(rowsAboutToBeInserted(QModelIndex, int, int)));
+        QSignalSpy rowInsertedSpy(&pm, SIGNAL(rowsInserted(QModelIndex, int, int)));
+        QSignalSpy rowATBRSpy(&pm, SIGNAL(rowsAboutToBeRemoved(QModelIndex, int, int)));
+        QSignalSpy rowRemovedSpy(&pm, SIGNAL(rowsRemoved(QModelIndex, int, int)));
+        QIdentityProxyModel i1;
+        QIdentityProxyModel i2;
         pm.addSourceModel(&i1);
         pm.addSourceModel(&i2);
 
@@ -96,7 +97,8 @@ private Q_SLOTS:
         KConcatenateRowsProxyModel pm;
 
         // When adding two empty models
-        QIdentityProxyModel i1, i2;
+        QIdentityProxyModel i1;
+        QIdentityProxyModel i2;
         pm.addSourceModel(&i1);
         pm.addSourceModel(&i2);
 
@@ -108,15 +110,15 @@ private Q_SLOTS:
 
         // Then the proxy should show 2 rows
         QCOMPARE(pm.rowCount(), 2);
-        QCOMPARE(extractRowTexts(&pm, 0), QString("ABC"));
-        QCOMPARE(extractRowTexts(&pm, 1), QString("DEF"));
+        QCOMPARE(extractRowTexts(&pm, 0), QStringLiteral("ABC"));
+        QCOMPARE(extractRowTexts(&pm, 1), QStringLiteral("DEF"));
 
         // ... and correct headers
-        QCOMPARE(pm.headerData(0, Qt::Horizontal).toString(), QString("H1"));
-        QCOMPARE(pm.headerData(1, Qt::Horizontal).toString(), QString("H2"));
-        QCOMPARE(pm.headerData(2, Qt::Horizontal).toString(), QString("H3"));
-        QCOMPARE(pm.headerData(0, Qt::Vertical).toString(), QString("One"));
-        QCOMPARE(pm.headerData(1, Qt::Vertical).toString(), QString("Two"));
+        QCOMPARE(pm.headerData(0, Qt::Horizontal).toString(), QStringLiteral("H1"));
+        QCOMPARE(pm.headerData(1, Qt::Horizontal).toString(), QStringLiteral("H2"));
+        QCOMPARE(pm.headerData(2, Qt::Horizontal).toString(), QStringLiteral("H3"));
+        QCOMPARE(pm.headerData(0, Qt::Vertical).toString(), QStringLiteral("One"));
+        QCOMPARE(pm.headerData(1, Qt::Vertical).toString(), QStringLiteral("Two"));
 
         QVERIFY(!pm.canFetchMore(QModelIndex()));
     }
@@ -127,22 +129,22 @@ private Q_SLOTS:
         KConcatenateRowsProxyModel pm;
         pm.addSourceModel(&mod);
         pm.addSourceModel(&mod2);
-        QSignalSpy dataChangedSpy(&pm, SIGNAL(dataChanged(QModelIndex,QModelIndex)));
+        QSignalSpy dataChangedSpy(&pm, SIGNAL(dataChanged(QModelIndex, QModelIndex)));
 
         // When a cell in a source model changes
         mod.item(0, 0)->setData("a", Qt::EditRole);
 
         // Then the change should be notified to the proxy
         QCOMPARE(dataChangedSpy.count(), 1);
-        QCOMPARE(dataChangedSpy.at(0).at(0).value<QModelIndex>(), pm.index(0, 0));
-        QCOMPARE(extractRowTexts(&pm, 0), QString("aBC"));
+        QCOMPARE(dataChangedSpy.at(0).at(0).toModelIndex(), pm.index(0, 0));
+        QCOMPARE(extractRowTexts(&pm, 0), QStringLiteral("aBC"));
 
         // Same test with the other model
         mod2.item(0, 2)->setData("f", Qt::EditRole);
 
         QCOMPARE(dataChangedSpy.count(), 2);
-        QCOMPARE(dataChangedSpy.at(1).at(0).value<QModelIndex>(), pm.index(1, 2));
-        QCOMPARE(extractRowTexts(&pm, 1), QString("DEf"));
+        QCOMPARE(dataChangedSpy.at(1).at(0).toModelIndex(), pm.index(1, 2));
+        QCOMPARE(extractRowTexts(&pm, 1), QStringLiteral("DEf"));
     }
 
     void shouldHandleSetData()
@@ -151,22 +153,22 @@ private Q_SLOTS:
         KConcatenateRowsProxyModel pm;
         pm.addSourceModel(&mod);
         pm.addSourceModel(&mod2);
-        QSignalSpy dataChangedSpy(&pm, SIGNAL(dataChanged(QModelIndex,QModelIndex)));
+        QSignalSpy dataChangedSpy(&pm, SIGNAL(dataChanged(QModelIndex, QModelIndex)));
 
         // When changing a cell using setData
         pm.setData(pm.index(0, 0), "a", Qt::EditRole);
 
         // Then the change should be notified to the proxy
         QCOMPARE(dataChangedSpy.count(), 1);
-        QCOMPARE(dataChangedSpy.at(0).at(0).value<QModelIndex>(), pm.index(0, 0));
-        QCOMPARE(extractRowTexts(&pm, 0), QString("aBC"));
+        QCOMPARE(dataChangedSpy.at(0).at(0).toModelIndex(), pm.index(0, 0));
+        QCOMPARE(extractRowTexts(&pm, 0), QStringLiteral("aBC"));
 
         // Same test with the other model
         pm.setData(pm.index(1, 2), "f", Qt::EditRole);
 
         QCOMPARE(dataChangedSpy.count(), 2);
-        QCOMPARE(dataChangedSpy.at(1).at(0).value<QModelIndex>(), pm.index(1, 2));
-        QCOMPARE(extractRowTexts(&pm, 1), QString("DEf"));
+        QCOMPARE(dataChangedSpy.at(1).at(0).toModelIndex(), pm.index(1, 2));
+        QCOMPARE(extractRowTexts(&pm, 1), QStringLiteral("DEf"));
     }
 
     void shouldHandleRowInsertionAndRemoval()
@@ -175,8 +177,8 @@ private Q_SLOTS:
         KConcatenateRowsProxyModel pm;
         pm.addSourceModel(&mod);
         pm.addSourceModel(&mod2);
-        QSignalSpy rowATBISpy(&pm, SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)));
-        QSignalSpy rowInsertedSpy(&pm, SIGNAL(rowsInserted(QModelIndex,int,int)));
+        QSignalSpy rowATBISpy(&pm, SIGNAL(rowsAboutToBeInserted(QModelIndex, int, int)));
+        QSignalSpy rowInsertedSpy(&pm, SIGNAL(rowsInserted(QModelIndex, int, int)));
 
         // When a source model inserts a new row
         QList<QStandardItem *> row;
@@ -186,16 +188,16 @@ private Q_SLOTS:
         mod2.insertRow(0, row);
 
         // Then the proxy should notify its users and show changes
-        QCOMPARE(rowSpyToText(rowATBISpy), QString("1,1"));
-        QCOMPARE(rowSpyToText(rowInsertedSpy), QString("1,1"));
+        QCOMPARE(rowSpyToText(rowATBISpy), QStringLiteral("1,1"));
+        QCOMPARE(rowSpyToText(rowInsertedSpy), QStringLiteral("1,1"));
         QCOMPARE(pm.rowCount(), 3);
-        QCOMPARE(extractRowTexts(&pm, 0), QString("ABC"));
-        QCOMPARE(extractRowTexts(&pm, 1), QString("123"));
-        QCOMPARE(extractRowTexts(&pm, 2), QString("DEF"));
+        QCOMPARE(extractRowTexts(&pm, 0), QStringLiteral("ABC"));
+        QCOMPARE(extractRowTexts(&pm, 1), QStringLiteral("123"));
+        QCOMPARE(extractRowTexts(&pm, 2), QStringLiteral("DEF"));
 
         // When removing that row
-        QSignalSpy rowATBRSpy(&pm, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)));
-        QSignalSpy rowRemovedSpy(&pm, SIGNAL(rowsRemoved(QModelIndex,int,int)));
+        QSignalSpy rowATBRSpy(&pm, SIGNAL(rowsAboutToBeRemoved(QModelIndex, int, int)));
+        QSignalSpy rowRemovedSpy(&pm, SIGNAL(rowsRemoved(QModelIndex, int, int)));
         mod2.removeRow(0);
 
         // Then the proxy should notify its users and show changes
@@ -206,8 +208,8 @@ private Q_SLOTS:
         QCOMPARE(rowRemovedSpy.at(0).at(1).toInt(), 1);
         QCOMPARE(rowRemovedSpy.at(0).at(2).toInt(), 1);
         QCOMPARE(pm.rowCount(), 2);
-        QCOMPARE(extractRowTexts(&pm, 0), QString("ABC"));
-        QCOMPARE(extractRowTexts(&pm, 1), QString("DEF"));
+        QCOMPARE(extractRowTexts(&pm, 0), QStringLiteral("ABC"));
+        QCOMPARE(extractRowTexts(&pm, 1), QStringLiteral("DEF"));
 
         // When removing the last row from mod2
         rowATBRSpy.clear();
@@ -222,7 +224,7 @@ private Q_SLOTS:
         QCOMPARE(rowRemovedSpy.at(0).at(1).toInt(), 1);
         QCOMPARE(rowRemovedSpy.at(0).at(2).toInt(), 1);
         QCOMPARE(pm.rowCount(), 1);
-        QCOMPARE(extractRowTexts(&pm, 0), QString("ABC"));
+        QCOMPARE(extractRowTexts(&pm, 0), QStringLiteral("ABC"));
     }
 
     void shouldAggregateAnotherModelThenRemoveModels()
@@ -236,24 +238,24 @@ private Q_SLOTS:
         mod3.appendRow(makeStandardItems(QStringList() << QStringLiteral("1") << QStringLiteral("2") << QStringLiteral("3")));
         mod3.appendRow(makeStandardItems(QStringList() << QStringLiteral("4") << QStringLiteral("5") << QStringLiteral("6")));
 
-        QSignalSpy rowATBISpy(&pm, SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)));
-        QSignalSpy rowInsertedSpy(&pm, SIGNAL(rowsInserted(QModelIndex,int,int)));
+        QSignalSpy rowATBISpy(&pm, SIGNAL(rowsAboutToBeInserted(QModelIndex, int, int)));
+        QSignalSpy rowInsertedSpy(&pm, SIGNAL(rowsInserted(QModelIndex, int, int)));
 
         // When adding the new source model
         pm.addSourceModel(&mod3);
 
         // Then the proxy should notify its users about the two rows inserted
-        QCOMPARE(rowSpyToText(rowATBISpy), QString("2,3"));
-        QCOMPARE(rowSpyToText(rowInsertedSpy), QString("2,3"));
+        QCOMPARE(rowSpyToText(rowATBISpy), QStringLiteral("2,3"));
+        QCOMPARE(rowSpyToText(rowInsertedSpy), QStringLiteral("2,3"));
         QCOMPARE(pm.rowCount(), 4);
-        QCOMPARE(extractRowTexts(&pm, 0), QString("ABC"));
-        QCOMPARE(extractRowTexts(&pm, 1), QString("DEF"));
-        QCOMPARE(extractRowTexts(&pm, 2), QString("123"));
-        QCOMPARE(extractRowTexts(&pm, 3), QString("456"));
+        QCOMPARE(extractRowTexts(&pm, 0), QStringLiteral("ABC"));
+        QCOMPARE(extractRowTexts(&pm, 1), QStringLiteral("DEF"));
+        QCOMPARE(extractRowTexts(&pm, 2), QStringLiteral("123"));
+        QCOMPARE(extractRowTexts(&pm, 3), QStringLiteral("456"));
 
         // When removing that source model again
-        QSignalSpy rowATBRSpy(&pm, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)));
-        QSignalSpy rowRemovedSpy(&pm, SIGNAL(rowsRemoved(QModelIndex,int,int)));
+        QSignalSpy rowATBRSpy(&pm, SIGNAL(rowsAboutToBeRemoved(QModelIndex, int, int)));
+        QSignalSpy rowRemovedSpy(&pm, SIGNAL(rowsRemoved(QModelIndex, int, int)));
         pm.removeSourceModel(&mod3);
 
         // Then the proxy should notify its users about the row removed
@@ -264,8 +266,8 @@ private Q_SLOTS:
         QCOMPARE(rowRemovedSpy.at(0).at(1).toInt(), 2);
         QCOMPARE(rowRemovedSpy.at(0).at(2).toInt(), 3);
         QCOMPARE(pm.rowCount(), 2);
-        QCOMPARE(extractRowTexts(&pm, 0), QString("ABC"));
-        QCOMPARE(extractRowTexts(&pm, 1), QString("DEF"));
+        QCOMPARE(extractRowTexts(&pm, 0), QStringLiteral("ABC"));
+        QCOMPARE(extractRowTexts(&pm, 1), QStringLiteral("DEF"));
 
         // When removing model 2
         rowATBRSpy.clear();
@@ -278,7 +280,7 @@ private Q_SLOTS:
         QCOMPARE(rowRemovedSpy.at(0).at(1).toInt(), 1);
         QCOMPARE(rowRemovedSpy.at(0).at(2).toInt(), 1);
         QCOMPARE(pm.rowCount(), 1);
-        QCOMPARE(extractRowTexts(&pm, 0), QString("ABC"));
+        QCOMPARE(extractRowTexts(&pm, 0), QStringLiteral("ABC"));
 
         // When removing model 1
         rowATBRSpy.clear();
@@ -299,20 +301,20 @@ private Q_SLOTS:
         KConcatenateRowsProxyModel pm;
         pm.addSourceModel(&mod);
         pm.addSourceModel(&mod2);
-        QSignalSpy colATBISpy(&pm, SIGNAL(columnsAboutToBeInserted(QModelIndex,int,int)));
-        QSignalSpy colInsertedSpy(&pm, SIGNAL(columnsInserted(QModelIndex,int,int)));
+        QSignalSpy colATBISpy(&pm, SIGNAL(columnsAboutToBeInserted(QModelIndex, int, int)));
+        QSignalSpy colInsertedSpy(&pm, SIGNAL(columnsInserted(QModelIndex, int, int)));
 
         // When the first source model inserts a new column
         QCOMPARE(mod.columnCount(), 3);
         mod.setColumnCount(4);
 
         // Then the proxy should notify its users and show changes
-        QCOMPARE(rowSpyToText(colATBISpy), QString("3,3"));
-        QCOMPARE(rowSpyToText(colInsertedSpy), QString("3,3"));
+        QCOMPARE(rowSpyToText(colATBISpy), QStringLiteral("3,3"));
+        QCOMPARE(rowSpyToText(colInsertedSpy), QStringLiteral("3,3"));
         QCOMPARE(pm.rowCount(), 2);
         QCOMPARE(pm.columnCount(), 4);
-        QCOMPARE(extractRowTexts(&pm, 0), QString("ABC "));
-        QCOMPARE(extractRowTexts(&pm, 1), QString("DEF "));
+        QCOMPARE(extractRowTexts(&pm, 0), QStringLiteral("ABC "));
+        QCOMPARE(extractRowTexts(&pm, 1), QStringLiteral("DEF "));
     }
 
     void shouldPropagateLayoutChanged()
@@ -337,9 +339,9 @@ private Q_SLOTS:
         qsfpm.setSourceModel(&mod3);
         pm.addSourceModel(&qsfpm);
 
-        QCOMPARE(extractRowTexts(&pm, 0), QString("ABC"));
-        QCOMPARE(extractRowTexts(&pm, 1), QString("123"));
-        QCOMPARE(extractRowTexts(&pm, 2), QString("456"));
+        QCOMPARE(extractRowTexts(&pm, 0), QStringLiteral("ABC"));
+        QCOMPARE(extractRowTexts(&pm, 1), QStringLiteral("123"));
+        QCOMPARE(extractRowTexts(&pm, 2), QStringLiteral("456"));
 
         // And a selection (row 1)
         QItemSelectionModel selection(&pm);
@@ -358,9 +360,9 @@ private Q_SLOTS:
         qsfpm.sort(0, Qt::DescendingOrder);
 
         // Then the proxy should emit the layoutChanged signals, and show re-sorted data
-        QCOMPARE(extractRowTexts(&pm, 0), QString("ABC"));
-        QCOMPARE(extractRowTexts(&pm, 1), QString("456"));
-        QCOMPARE(extractRowTexts(&pm, 2), QString("123"));
+        QCOMPARE(extractRowTexts(&pm, 0), QStringLiteral("ABC"));
+        QCOMPARE(extractRowTexts(&pm, 1), QStringLiteral("456"));
+        QCOMPARE(extractRowTexts(&pm, 2), QStringLiteral("123"));
         QCOMPARE(layoutATBCSpy.count(), 1);
         QCOMPARE(layoutChangedSpy.count(), 1);
 
@@ -395,24 +397,24 @@ private Q_SLOTS:
         qsfpm.setSourceModel(&mod3);
         pm.addSourceModel(&qsfpm);
 
-        QCOMPARE(extractRowTexts(&pm, 0), QString("ABC"));
-        QCOMPARE(extractRowTexts(&pm, 1), QString("123"));
-        QCOMPARE(extractRowTexts(&pm, 2), QString("456"));
-        QSignalSpy rowATBRSpy(&pm, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)));
-        QSignalSpy rowRemovedSpy(&pm, SIGNAL(rowsRemoved(QModelIndex,int,int)));
-        QSignalSpy rowATBISpy(&pm, SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)));
-        QSignalSpy rowInsertedSpy(&pm, SIGNAL(rowsInserted(QModelIndex,int,int)));
+        QCOMPARE(extractRowTexts(&pm, 0), QStringLiteral("ABC"));
+        QCOMPARE(extractRowTexts(&pm, 1), QStringLiteral("123"));
+        QCOMPARE(extractRowTexts(&pm, 2), QStringLiteral("456"));
+        QSignalSpy rowATBRSpy(&pm, SIGNAL(rowsAboutToBeRemoved(QModelIndex, int, int)));
+        QSignalSpy rowRemovedSpy(&pm, SIGNAL(rowsRemoved(QModelIndex, int, int)));
+        QSignalSpy rowATBISpy(&pm, SIGNAL(rowsAboutToBeInserted(QModelIndex, int, int)));
+        QSignalSpy rowInsertedSpy(&pm, SIGNAL(rowsInserted(QModelIndex, int, int)));
 
         // When changing the source model of the QSFPM
         qsfpm.setSourceModel(&mod2);
 
         // Then the proxy should emit the row removed/inserted signals, and show the new data
-        QCOMPARE(extractRowTexts(&pm, 0), QString("ABC"));
-        QCOMPARE(extractRowTexts(&pm, 1), QString("DEF"));
-        QCOMPARE(rowSpyToText(rowATBRSpy), QString("1,2"));
-        QCOMPARE(rowSpyToText(rowRemovedSpy), QString("1,2"));
-        QCOMPARE(rowSpyToText(rowATBISpy), QString("1,1"));
-        QCOMPARE(rowSpyToText(rowInsertedSpy), QString("1,1"));
+        QCOMPARE(extractRowTexts(&pm, 0), QStringLiteral("ABC"));
+        QCOMPARE(extractRowTexts(&pm, 1), QStringLiteral("DEF"));
+        QCOMPARE(rowSpyToText(rowATBRSpy), QStringLiteral("1,2"));
+        QCOMPARE(rowSpyToText(rowRemovedSpy), QStringLiteral("1,2"));
+        QCOMPARE(rowSpyToText(rowATBISpy), QStringLiteral("1,1"));
+        QCOMPARE(rowSpyToText(rowInsertedSpy), QStringLiteral("1,1"));
     }
 
 private:
