@@ -1,28 +1,15 @@
 /*
-    Copyright (c) 2016 Ableton AG <info@ableton.com>
-        Author Stephen Kelly <stephen.kelly@ableton.com>
+    SPDX-FileCopyrightText: 2016 Ableton AG <info@ableton.com>
+    SPDX-FileContributor: Stephen Kelly <stephen.kelly@ableton.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <QSignalSpy>
-#include <QTest>
-#include <QStringListModel>
 #include <QIdentityProxyModel>
 #include <QItemSelection>
+#include <QSignalSpy>
+#include <QStringListModel>
+#include <QTest>
 
 #include "kmodelindexproxymapper.h"
 
@@ -179,9 +166,9 @@ void ModelIndexProxyMapperTest::crossWires()
     QCOMPARE(spy.count(), 0);
 
     {
-    auto leftIdx = proxy_left3.index(0, 0);
-    auto rightIdx = proxy_right4.index(0, 0);
-    QCOMPARE(mapper.mapLeftToRight(leftIdx), rightIdx);
+        auto leftIdx = proxy_left3.index(0, 0);
+        auto rightIdx = proxy_right4.index(0, 0);
+        QCOMPARE(mapper.mapLeftToRight(leftIdx), rightIdx);
     }
 
     proxy_right4.setSourceModel(&proxy_left2);
@@ -190,9 +177,9 @@ void ModelIndexProxyMapperTest::crossWires()
     QCOMPARE(spy.count(), 0);
 
     {
-    auto leftIdx = proxy_left3.index(0, 0);
-    auto rightIdx = proxy_right4.index(0, 0);
-    QCOMPARE(mapper.mapLeftToRight(leftIdx), rightIdx);
+        auto leftIdx = proxy_left3.index(0, 0);
+        auto rightIdx = proxy_right4.index(0, 0);
+        QCOMPARE(mapper.mapLeftToRight(leftIdx), rightIdx);
     }
 }
 
